AvroSchema

Trait AvroSchema 

pub trait AvroSchema {
    // Required method
    fn get_schema() -> Schema;
}
Trait for types that serve as an Avro data model. Derive implementation available through derive feature. Do not implement directly! Implement apache_avro::schema::derive::AvroSchemaComponent to get this trait through a blanket implementation.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors